# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS & White Box as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "wbel"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# perl_vendorlib/perl_vendorarch not defined by default prior to F-2
%{!?perl_vendorlib: %global perl_vendorlib %(eval "`perl -V:installvendorlib`"; echo $installvendorlib)}

# Perl::Critic not available prior to FC-5 and Perl 5.8.8
%global have_perl_critic %(perl -e 'print (($^V and $^V ge 5.8.8) ? 1 : 0);')

# We need to tweak the test suite if we have an old version of Test::More
%global old_test_more %(perl -MTest::More -e 'printf "%d\\n", $Test::More::VERSION < 0.88 ? 1 : 0;' 2>/dev/null || echo 0)

# Pick up the right dictionary for the spell check
%if %(perl -e 'print (($^V and $^V ge 5.10.0) ? 1 : 0);')
%global speller hunspell
%else
%global speller aspell
%endif

Name:		perl-Symbol-Util
Version:	0.0202
Release:	7.%{__distinit}%{__distvers}
Summary:	Additional utilities for Perl symbols manipulation
License:	GPL+ or Artistic
Group:		Development/Libraries
URL:		http://search.cpan.org/dist/Symbol-Util/
Source0:	http://search.cpan.org/CPAN/authors/id/D/DE/DEXTER/Symbol-Util-%{version}.tar.gz
Source1:	C0B10A5B.pub
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
BuildArch:	noarch
BuildRequires:	perl(ExtUtils::MakeMaker)
BuildRequires:	perl(Test::More)
# Release test requirements
BuildRequires:	perl(File::Slurp)
BuildRequires:	perl(Test::CheckChanges)
BuildRequires:	perl(Test::Distribution)
BuildRequires:	perl(Test::Kwalitee)
BuildRequires:	perl(Test::MinimumVersion)
%if %{have_perl_critic}
BuildRequires:	perl(Test::Perl::Critic)
%endif
BuildRequires:	perl(Test::Pod)
BuildRequires:	perl(Test::Pod::Coverage)
BuildRequires:	perl(Test::Signature)
BuildRequires:	perl(Test::Spelling)
%if %(perl -e 'print (($] >= 5.008001) ? 1 : 0)')
BuildRequires:	%{speller}-en
%else
BuildRequires:	%{speller}-en-gb
%endif
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))

%description
This module provides a set of additional functions useful for Perl symbols
manipulation.

%prep
%setup -q -c -n Symbol-Util

# Copy up documentation for convenience with %%doc
cp -a Symbol-Util-%{version}/{Changes,eg,LICENSE,README} .

# Clean up permissions where necessary
chmod -c -x,u+w eg/*

# Create a GPG directory for testing, to avoid using ~/.gnupg
mkdir --mode=0700 gnupghome
GNUPGHOME=$(pwd)/gnupghome gpg --import %{SOURCE1}

%build
cd Symbol-Util-%{version}
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}
cd -

%install
rm -rf %{buildroot}
make -C Symbol-Util-%{version} pure_install PERL_INSTALL_ROOT=%{buildroot}
find %{buildroot} -type f -name .packlist -exec rm -f {} ';'
find %{buildroot} -depth -type d -exec rmdir {} ';' 2>/dev/null
%{_fixperms} %{buildroot}

%check
export GNUPGHOME=$(pwd)/gnupghome
cd Symbol-Util-%{version}

# === MAIN TEST SUITE === #
make test

# ===  RELEASE TESTS  === #
RELEASE_TESTS="$(echo xt/*.t | sed 's|xt/copyright.t||')"
# Don't run the copyright test as it will fail after the year of module release
RELEASE_TESTS="$(echo $RELEASE_TESTS | sed 's|xt/copyright.t||')"
# Don't run the Perl::Critic test if we don't have Test::Perl::Critic
%if !%{have_perl_critic}
RELEASE_TESTS="$(echo $RELEASE_TESTS | sed 's|xt/perlcritic.t||')"
%endif
# Changes test needs tweaking if we don't have Test::More >= 0.88,
# but don't do it yet as it would cause the signature test to fail
%if %{old_test_more}
RELEASE_TESTS="$(echo $RELEASE_TESTS | sed 's|xt/check_changes.t||')"
%endif
make test TEST_FILES="$RELEASE_TESTS"
# Now try the Changes test if we didn't run it before
%if %{old_test_more}
sed -e 's|^use Test::CheckChanges;|use Test::More tests => 1;\n&|' xt/check_changes.t > xt/check_changes_compat.t
make test TEST_FILES=xt/check_changes_compat.t
rm xt/check_changes_compat.t
%endif

cd -

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root,-)
%doc Changes eg LICENSE README
%{perl_vendorlib}/Symbol/
%{_mandir}/man3/Symbol::Util.3pm*

%changelog
* Fri May  6 2011 Paul Howarth <paul@city-fan.org> - 0.0202-7
- Import from Fedora

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.0202-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Wed Dec 22 2010 Marcela Maslanova <mmaslano@redhat.com> - 0.0202-5
- Rebuild to fix problems with vendorarch/lib (#661697)

* Tue Jun 22 2010 Petr Pisar <ppisar@redhat.com> - 0.0202-4
- Rebuild against perl-5.12

* Tue May 04 2010 Emmanuel Seyman <emmanuel.seyman@club-internet.fr> - 0.0202-3
- Remove perl from BuildRequires

* Mon May 03 2010 Emmanuel Seyman <emmanuel.seyman@club-internet.fr> - 0.0202-2
- Add missing BuildRequires

* Mon Apr 12 2010 Emmanuel Seyman <emmanuel.seyman@club-internet.fr> - 0.0202-1
- Specfile autogenerated by cpanspec 1.78
